# QURI Parts OpenQASM

QURI Parts OpenQASM is a support library for using OpenQASM 3 with QURI Parts.

Note: some gates (SqrtX, SqrtXdag, SqrtY, SqrtYdag) are not implemented yet.

## Documentation

[QURI Parts Documentation](https://quri-parts.qunasys.com)

## Installation

```
pip install quri-parts-openqasm
```

## License

Apache License 2.0
